From fdf546a221bacd4fc5937e1173d3ac2fe96a7ec2 Mon Sep 17 00:00:00 2001
From: Ryan Pavlik <rpavlik@iastate.edu>
Date: Fri, 21 Oct 2011 12:32:49 -0500
Subject: [PATCH 04/43] os/utils.c: Windows non-cygwin get only stubs for
 Lock/UnlockServer

MinGW and MSVC lack the POSIX functions to compile the locking code.
---
 os/utils.c |   16 ++++++++++++++++
 1 files changed, 16 insertions(+), 0 deletions(-)

diff --git a/os/utils.c b/os/utils.c
index 2b8c119..97e6a6c 100644
--- a/os/utils.c
+++ b/os/utils.c
@@ -235,6 +235,15 @@ OsSignal(int sig, OsSigHandlerPtr handler)
 #define LOCK_PREFIX "/.X"
 #define LOCK_SUFFIX "-lock"
 
+#if defined(WIN32) && !defined(__CYGWIN__)
+void
+LockServer(void)
+{}
+
+void
+UnlockServer(void)
+{}
+#else
 static Bool StillLocking = FALSE;
 static char LockFile[PATH_MAX];
 static Bool nolock = FALSE;
@@ -382,6 +391,7 @@ UnlockServer(void)
   }
 }
 
+#endif /* not windows non-cygwin */
 /* Force connections to close on SIGHUP from init */
 
 void
@@ -502,7 +512,9 @@ void UseMsg(void)
 #ifdef RLIMIT_STACK
     ErrorF("-ls int                limit stack space to N Kb\n");
 #endif
+#if !defined(WIN32) || defined(__CYGWIN__)
     ErrorF("-nolock                disable the locking mechanism\n");
+#endif
     ErrorF("-nolisten string       don't listen on protocol\n");
     ErrorF("-noreset               don't reset after last client exists\n");
     ErrorF("-background [none]     create root window with no background\n");
@@ -750,6 +762,8 @@ ProcessCommandLine(int argc, char *argv[])
 		UseMsg();
 	}
 #endif
+
+#if !defined(WIN32) || defined(__CYGWIN__)
 	else if ( strcmp ( argv[i], "-nolock") == 0)
 	{
 #if !defined(WIN32) && !defined(__CYGWIN__)
@@ -759,6 +773,8 @@ ProcessCommandLine(int argc, char *argv[])
 #endif
 	    nolock = TRUE;
 	}
+#endif
+
 	else if ( strcmp( argv[i], "-nolisten") == 0)
 	{
             if(++i < argc) {
-- 
1.7.7.1

